@@ -291,7 +291,7 @@ class BopOperator(IndicatorOperator):
 # returns
 ###############
 
-class HistoricalReturnOperator(IndicatorOperator):
+class ReturnsOperator(IndicatorOperator):
     @staticmethod
     def get_column_names():
         return ["Returns"]
@@ -314,33 +314,6 @@ class HistoricalReturnOperator(IndicatorOperator):
         return data
 
 
-# # Todo: needs test, I change the logic
-# class ForwardReturnOperator(IndicatorOperator):
-#     @staticmethod
-#     def get_column_names():
-#         return ["Return-Forwads-wrong"]
-#
-#     def __init__(self, prefix, period, magnifier_multiplier=10000):
-#         self.prefix = prefix
-#         self.period = period
-#         self.magnifier_multiplier = magnifier_multiplier
-#
-#     def apply(self, data: IndicatorData) -> IndicatorData:
-#         logger = logging.getLogger(__name__)
-#         # Compute Forward Returns
-#         logger.info("Forward Returns =================================")
-#         close_prices = data["Close"]
-#         return_col = self.get_column_names()[0]
-#
-#         fwd_col = self.calculate_final_column_name(prefix=self.prefix, col_name=self.get_column_names()[0],
-#                                                     period=self.period)
-#
-#         data[fwd_col] = close_prices \
-#             .pct_change(self.period) \
-#             .shift(-self.period)
-#         return data
-
-
 ###############
 # max min operators
 ###############
