@@ -162,7 +162,7 @@ class FeatureCreatorManager:
 
 
         features = f_common.combine_features(features_list=[features_lags, features])
-        features = f_common.add_ohlc(data=features, ohlc=instances)
+        features = f_common.add_ohlc(data=features, ohlc=data)
 
 
         features, targets, all = f_common.align_features_and_targets(features=features, targets=targets)
