@@ -31,7 +31,10 @@ def test_random_with_cv():
 
     cv = CustomTsCv(train_n=10, test_n=3, sample_n=sample_n, train_shuffle_block_size=None)
 
-    metrics = ['neg_mean_absolute_percentage_error', 'neg_mean_absolute_error']
+    metrics = ['neg_mean_absolute_percentage_error',
+               'neg_mean_absolute_error',
+               'binary_returns_avg',
+               'binary_returns']
 
     # act
     result = run_benchmarking(models=models, targets=targets, features=features, cv=cv, metrics=metrics)
